@@ -1,5 +1,6 @@
 import { get } from "svelte/store";
 
+import type { Entry } from "./entries";
 import { baseURL } from "./stores";
 import { urlSyncedParams } from "./stores/url";
 
@@ -32,3 +33,15 @@ export function urlFor(
   const urlParamString = urlParams.toString();
   return urlParamString ? `${url}?${urlParams.toString()}` : url;
 }
+
+/** URL for the editor to the source location of an entry. */
+export function urlForSource(entry: Entry): string {
+  const file_path = entry.meta.filename.toString();
+  const line = entry.meta.lineno.toString();
+  return urlFor("editor/", { file_path, line });
+}
+
+/** URL for the account report. */
+export function urlForAccount(account: string): string {
+  return urlFor(`account/${account}/`);
+}
