@@ -26,13 +26,16 @@ export const ledgerDataValidator = object({
   currencies: array(string),
   errors: number,
   favaOptions: object({
-    "auto-reload": boolean,
-    "currency-column": number,
+    auto_reload: boolean,
+    currency_column: number,
     indent: number,
     locale: union(string, constant(null)),
-    "insert-entry": array(
+    insert_entry: array(
       object({ date: string, filename: string, lineno: number, re: string })
     ),
+    journal_show: array(string),
+    journal_show_document: array(string),
+    journal_show_transaction: array(string),
   }),
   have_excel: boolean,
   incognito: boolean,
