@@ -1,5 +1,5 @@
 """Specify types for the flask application context."""
-from typing import Optional
+from __future__ import annotations
 
 import flask
 
@@ -10,7 +10,7 @@ from fava.util.date import Interval
 class Context:
     """The allowed context values."""
 
-    beancount_file_slug: Optional[str]
+    beancount_file_slug: str | None
     conversion: str
     interval: Interval
     ledger: FavaLedger
