@@ -1,4 +1,6 @@
 """This module provides the data required by Fava's reports."""
+from __future__ import annotations
+
 import copy
 import datetime
 from operator import itemgetter
@@ -6,21 +8,14 @@ from os.path import basename
 from os.path import dirname
 from os.path import join
 from os.path import normpath
-from typing import Any
-from typing import Dict
 from typing import Iterable
-from typing import List
-from typing import Optional
-from typing import Tuple
 
-from beancount import loader  # type: ignore
 from beancount.core import realization
 from beancount.core.account_types import AccountTypes
 from beancount.core.account_types import get_account_sign
 from beancount.core.compare import hash_entry
 from beancount.core.data import Balance
 from beancount.core.data import Close
-from beancount.core.data import Commodity
 from beancount.core.data import Directive
 from beancount.core.data import Document
 from beancount.core.data import Entries
@@ -37,9 +32,11 @@ from beancount.core.inventory import Inventory
 from beancount.core.number import Decimal
 from beancount.core.prices import build_price_map
 from beancount.core.prices import get_all_prices
+from beancount.loader import _load  # type: ignore
+from beancount.loader import load_file
 from beancount.parser.options import get_account_types
 from beancount.parser.options import OPTIONS_DEFAULTS
-from beancount.utils.encryption import is_encrypted_file  # type: ignore
+from beancount.utils.encryption import is_encrypted_file
 
 from fava.core._compat import FLAG_UNREALIZED
 from fava.core.accounts import AccountDict
@@ -49,7 +46,6 @@ from fava.core.budgets import BudgetModule
 from fava.core.charts import ChartModule
 from fava.core.entries_by_type import group_entries_by_type
 from fava.core.extensions import ExtensionModule
-from fava.core.fava_options import DEFAULTS
 from fava.core.fava_options import FavaOptions
 from fava.core.fava_options import parse_options
 from fava.core.file import FileModule
@@ -84,9 +80,9 @@ class Filters:
 
     def set(
         self,
-        account: Optional[str] = None,
-        filter: Optional[str] = None,  # pylint: disable=redefined-builtin
-        time: Optional[str] = None,
+        account: str | None = None,
+        filter: str | None = None,  # pylint: disable=redefined-builtin
+        time: str | None = None,
     ) -> bool:
         """Set the filters and check if one of them changed."""
         return any(
@@ -133,7 +129,7 @@ class FavaLedger:
         "all_entries_by_type",
         "all_root_account",
         "beancount_file_path",
-        "commodities",
+        "commodity_names",
         "_date_first",
         "_date_last",
         "entries",
@@ -198,7 +194,7 @@ class FavaLedger:
         self.all_entries_by_type = group_entries_by_type([])
 
         #: A list of all errors reported by Beancount.
-        self.errors: List[BeancountError] = []
+        self.errors: list[BeancountError] = []
 
         #: A Beancount options map.
         self.options: BeancountOptions = OPTIONS_DEFAULTS
@@ -206,14 +202,14 @@ class FavaLedger:
         #: A dict containing information about the accounts.
         self.accounts = AccountDict()
 
-        #: A dict containing information about the commodities
-        self.commodities: Dict[str, Commodity] = {}
+        #: A dict with commodity names (from the 'name' metadata)
+        self.commodity_names: dict[str, str] = {}
 
         #: A dict with all of Fava's option values.
-        self.fava_options: FavaOptions = DEFAULTS
+        self.fava_options: FavaOptions = FavaOptions()
 
-        self._date_first: Optional[datetime.date] = None
-        self._date_last: Optional[datetime.date] = None
+        self._date_first: datetime.date | None = None
+        self._date_last: datetime.date | None = None
 
         self.load_file()
 
@@ -222,11 +218,11 @@ class FavaLedger:
         # use the internal function to disable cache
         if not self._is_encrypted:
             # pylint: disable=protected-access
-            self.all_entries, self.errors, self.options = loader._load(
+            self.all_entries, self.errors, self.options = _load(
                 [(self.beancount_file_path, True)], None, None, None
             )
         else:
-            self.all_entries, self.errors, self.options = loader.load_file(
+            self.all_entries, self.errors, self.options = load_file(
                 self.beancount_file_path
             )
 
@@ -244,9 +240,11 @@ class FavaLedger:
         for close in self.all_entries_by_type.Close:
             self.accounts.setdefault(close.account).close_date = close.date
 
-        self.commodities = {}
+        self.commodity_names = {}
         for commodity in self.all_entries_by_type.Commodity:
-            self.commodities[commodity.currency] = commodity
+            name = commodity.meta.get("name")
+            if name:
+                self.commodity_names[commodity.currency] = name
 
         self.fava_options, errors = parse_options(
             self.all_entries_by_type.Custom
@@ -267,9 +265,9 @@ class FavaLedger:
     def filter(
         self,
         force: bool = False,
-        account: Optional[str] = None,
-        filter: Optional[str] = None,  # pylint: disable=redefined-builtin
-        time: Optional[str] = None,
+        account: str | None = None,
+        filter: str | None = None,  # pylint: disable=redefined-builtin
+        time: str | None = None,
     ) -> None:
         """Set and apply (if necessary) filters."""
         changed = self.filters.set(account=account, filter=filter, time=time)
@@ -295,7 +293,7 @@ class FavaLedger:
             self._date_last = self.filters.time.end_date
 
     @property
-    def end_date(self) -> Optional[datetime.date]:
+    def end_date(self) -> datetime.date | None:
         """The date to use for prices."""
         if self.filters.time:
             return self.filters.time.end_date
@@ -306,7 +304,7 @@ class FavaLedger:
         include_path = dirname(self.beancount_file_path)
         return normpath(join(include_path, *args))
 
-    def paths_to_watch(self) -> Tuple[List[str], List[str]]:
+    def paths_to_watch(self) -> tuple[list[str], list[str]]:
         """The paths to included files and document directories.
 
         Returns:
@@ -363,7 +361,7 @@ class FavaLedger:
     def root_tree_closed(self) -> Tree:
         """A root tree for the balance sheet."""
         tree = Tree(self.entries)
-        tree.cap(self.options, self.fava_options["unrealized"])
+        tree.cap(self.options, self.fava_options.unrealized)
         return tree
 
     def interval_balances(
@@ -371,9 +369,9 @@ class FavaLedger:
         interval: date.Interval,
         account_name: str,
         accumulate: bool = False,
-    ) -> Tuple[
-        List[realization.RealAccount],
-        List[Tuple[datetime.date, datetime.date]],
+    ) -> tuple[
+        list[realization.RealAccount],
+        list[tuple[datetime.date, datetime.date]],
     ]:
         """Balances by interval.
 
@@ -414,7 +412,7 @@ class FavaLedger:
 
     def account_journal(
         self, account_name: str, with_journal_children: bool = False
-    ) -> List[Tuple[Directive, List[Posting], Inventory, Inventory]]:
+    ) -> list[tuple[Directive, list[Posting], Inventory, Inventory]]:
         """Journal for an account.
 
         Args:
@@ -446,11 +444,11 @@ class FavaLedger:
         ]
 
     @property
-    def documents(self) -> List[Document]:
+    def documents(self) -> list[Document]:
         """All currently filtered documents."""
         return [e for e in self.entries if isinstance(e, Document)]
 
-    def events(self, event_type: Optional[str] = None) -> List[Event]:
+    def events(self, event_type: str | None = None) -> list[Event]:
         """List events (possibly filtered by type)."""
         events = [e for e in self.entries if isinstance(e, Event)]
         if event_type:
@@ -480,26 +478,43 @@ class FavaLedger:
                 f'No entry found for hash "{entry_hash}"'
             ) from exc
 
-    def context(self, entry_hash: str) -> Tuple[Directive, Any, str, str]:
+    def context(
+        self, entry_hash: str
+    ) -> tuple[
+        Directive,
+        dict[str, list[str]] | None,
+        dict[str, list[str]] | None,
+        str,
+        str,
+    ]:
         """Context for an entry.
 
         Arguments:
             entry_hash: Hash of entry.
 
         Returns:
-            A tuple ``(entry, balances, source_slice, sha256sum)`` of the
+            A tuple ``(entry, before, after, source_slice, sha256sum)`` of the
             (unique) entry with the given ``entry_hash``. If the entry is a
-            Balance or Transaction then ``balances`` is a 2-tuple containing
+            Balance or Transaction then ``before`` and ``after`` contain
             the balances before and after the entry of the affected accounts.
         """
         entry = self.get_entry(entry_hash)
-        balances = None
-        if isinstance(entry, (Balance, Transaction)):
-            balances = compute_entry_context(self.all_entries, entry)
         source_slice, sha256sum = get_entry_slice(entry)
-        return entry, balances, source_slice, sha256sum
+        if not isinstance(entry, (Balance, Transaction)):
+            return entry, None, None, source_slice, sha256sum
 
-    def commodity_pairs(self) -> List[Tuple[str, str]]:
+        balances = compute_entry_context(self.all_entries, entry)
+        before = {
+            acc: [pos.to_string() for pos in sorted(inv)]
+            for acc, inv in balances[0].items()
+        }
+        after = {
+            acc: [pos.to_string() for pos in sorted(inv)]
+            for acc, inv in balances[1].items()
+        }
+        return entry, before, after, source_slice, sha256sum
+
+    def commodity_pairs(self) -> list[tuple[str, str]]:
         """List pairs of commodities.
 
         Returns:
@@ -518,7 +533,7 @@ class FavaLedger:
 
     def prices(
         self, base: str, quote: str
-    ) -> List[Tuple[datetime.date, Decimal]]:
+    ) -> list[tuple[datetime.date, Decimal]]:
         """List all prices."""
         all_prices = get_all_prices(self.price_map, (base, quote))
 
@@ -536,7 +551,7 @@ class FavaLedger:
             ]
         return all_prices
 
-    def last_entry(self, account_name: str) -> Optional[Directive]:
+    def last_entry(self, account_name: str) -> Directive | None:
         """Get last entry of an account.
 
         Args:
@@ -572,7 +587,7 @@ class FavaLedger:
 
         raise FavaAPIException("Statement not found.")
 
-    def account_uptodate_status(self, account_name: str) -> Optional[str]:
+    def account_uptodate_status(self, account_name: str) -> str | None:
         """Status of the last balance or transaction.
 
         Args:
@@ -617,7 +632,7 @@ class FavaLedger:
         return self.accounts[account_name].close_date != datetime.date.max
 
     @staticmethod
-    def group_entries_by_type(entries: Entries) -> List[Tuple[str, Entries]]:
+    def group_entries_by_type(entries: Entries) -> list[tuple[str, Entries]]:
         """Group the given entries by type.
 
         Args:
@@ -627,21 +642,8 @@ class FavaLedger:
             A list of tuples (type, entries) consisting of the directive type
             as a string and the list of corresponding entries.
         """
-        groups: Dict[str, Entries] = {}
+        groups: dict[str, Entries] = {}
         for entry in entries:
             groups.setdefault(entry.__class__.__name__, []).append(entry)
 
         return sorted(list(groups.items()), key=itemgetter(0))
-
-    def commodity_name(self, commodity: str) -> Optional[str]:
-        """Return the 'name' field in metadata of a commodity
-        Args:
-            commodity: The commodity in string
-        Returns:
-            The 'name' field in metadata of a commodity if exists,
-            otherwise the input string is returned
-        """
-        commodity_ = self.commodities.get(commodity)
-        if commodity_:
-            return commodity_.meta.get("name")
-        return commodity
