@@ -1,15 +1,17 @@
 """Document path related helpers."""
+from __future__ import annotations
+
 import os
 from os import path
 from typing import TYPE_CHECKING
 
 from fava.helpers import FavaAPIException
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from fava.core import FavaLedger
 
 
-def is_document_or_import_file(filename: str, ledger: "FavaLedger") -> bool:
+def is_document_or_import_file(filename: str, ledger: FavaLedger) -> bool:
     """Check whether the filename is a document or in an import directory.
 
     Args:
@@ -23,7 +25,7 @@ def is_document_or_import_file(filename: str, ledger: "FavaLedger") -> bool:
         document.filename for document in ledger.all_entries_by_type.Document
     ]
     import_directories = [
-        ledger.join_path(d) for d in ledger.fava_options["import-dirs"]
+        ledger.join_path(d) for d in ledger.fava_options.import_dirs
     ]
     if filename in filenames:
         return True
@@ -34,7 +36,7 @@ def is_document_or_import_file(filename: str, ledger: "FavaLedger") -> bool:
 
 
 def filepath_in_document_folder(
-    documents_folder: str, account: str, filename: str, ledger: "FavaLedger"
+    documents_folder: str, account: str, filename: str, ledger: FavaLedger
 ) -> str:
     """File path for a document in the folder for an account.
 
