@@ -1,4 +1,6 @@
 """Reading/writing Beancount files."""
+from __future__ import annotations
+
 import datetime
 import re
 import threading
@@ -7,9 +9,6 @@ from codecs import encode
 from hashlib import sha256
 from operator import attrgetter
 from typing import Generator
-from typing import List
-from typing import Optional
-from typing import Tuple
 from typing import TYPE_CHECKING
 
 from beancount.core.data import Balance
@@ -33,7 +32,7 @@ from fava.core.module_base import FavaModule
 from fava.helpers import FavaAPIException
 from fava.util import next_key
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from fava.core import FavaLedger
 
 #: The flags to exclude when rendering entries.
@@ -56,11 +55,11 @@ def sha256_str(val: str) -> str:
 class FileModule(FavaModule):
     """Functions related to reading/writing to Beancount files."""
 
-    def __init__(self, ledger: "FavaLedger") -> None:
+    def __init__(self, ledger: FavaLedger) -> None:
         super().__init__(ledger)
         self.lock = threading.Lock()
 
-    def get_source(self, path: str) -> Tuple[str, str]:
+    def get_source(self, path: str) -> tuple[str, str]:
         """Get source files.
 
         Args:
@@ -124,7 +123,7 @@ class FileModule(FavaModule):
             self.ledger.changed()
             entry: Directive = self.ledger.get_entry(entry_hash)
             key = next_key(basekey, entry.meta)
-            indent = self.ledger.fava_options["indent"]
+            indent = self.ledger.fava_options.indent
             insert_metadata_in_file(
                 entry.meta["filename"],
                 entry.meta["lineno"],
@@ -165,10 +164,10 @@ class FileModule(FavaModule):
             self.ledger.changed()
             fava_options = self.ledger.fava_options
             for entry in sorted(entries, key=incomplete_sortkey):
-                insert_options = fava_options["insert-entry"]
-                currency_column = fava_options["currency-column"]
-                indent = fava_options["indent"]
-                fava_options["insert-entry"] = insert_entry(
+                insert_options = fava_options.insert_entry
+                currency_column = fava_options.currency_column
+                indent = fava_options.indent
+                fava_options.insert_entry = insert_entry(
                     entry,
                     self.ledger.beancount_file_path,
                     insert_options,
@@ -188,7 +187,7 @@ class FileModule(FavaModule):
         Yields:
             The entries rendered in Beancount format.
         """
-        indent = self.ledger.fava_options["indent"]
+        indent = self.ledger.fava_options.indent
         for entry in entries:
             if isinstance(entry, (Balance, Transaction)):
                 if isinstance(entry, Transaction) and entry.flag in EXCL_FLAGS:
@@ -198,12 +197,12 @@ class FileModule(FavaModule):
                 except (KeyError, FileNotFoundError):
                     yield _format_entry(
                         entry,
-                        self.ledger.fava_options["currency-column"],
+                        self.ledger.fava_options.currency_column,
                         indent,
                     )
 
 
-def incomplete_sortkey(entry: Directive) -> Tuple[datetime.date, int]:
+def incomplete_sortkey(entry: Directive) -> tuple[datetime.date, int]:
     """Sortkey for entries that might have incomplete metadata."""
     return (entry.date, SORT_ORDER.get(type(entry), 0))
 
@@ -222,7 +221,7 @@ def insert_metadata_in_file(
         file.write("".join(contents))
 
 
-def find_entry_lines(lines: List[str], lineno: int) -> List[str]:
+def find_entry_lines(lines: list[str], lineno: int) -> list[str]:
     """Lines of entry starting at lineno.
 
     Args:
@@ -241,7 +240,7 @@ def find_entry_lines(lines: List[str], lineno: int) -> List[str]:
         entry_lines.append(line)
 
 
-def get_entry_slice(entry: Directive) -> Tuple[str, str]:
+def get_entry_slice(entry: Directive) -> tuple[str, str]:
     """Get slice of the source file for an entry.
 
     Args:
@@ -301,10 +300,10 @@ def save_entry_slice(
 def insert_entry(
     entry: Directive,
     default_filename: str,
-    insert_options: List[InsertEntryOption],
+    insert_options: list[InsertEntryOption],
     currency_column: int,
     indent: int,
-) -> List[InsertEntryOption]:
+) -> list[InsertEntryOption]:
     """Insert an entry.
 
     Args:
@@ -359,9 +358,9 @@ def _format_entry(entry: Directive, currency_column: int, indent: int) -> str:
 
 def find_insert_position(
     entry: Directive,
-    insert_options: List[InsertEntryOption],
+    insert_options: list[InsertEntryOption],
     default_filename: str,
-) -> Tuple[str, Optional[int]]:
+) -> tuple[str, int | None]:
     """Find insert position for an entry.
 
     Args:
