@@ -1,11 +1,13 @@
 """Account balance trees."""
+from __future__ import annotations
+
 import collections
 import datetime
+from dataclasses import dataclass
 from typing import Dict
 from typing import Generator
 from typing import Iterable
-from typing import List
-from typing import Optional
+from typing import TYPE_CHECKING
 
 from beancount.core import account
 from beancount.core import convert
@@ -16,17 +18,19 @@ from beancount.core.prices import PriceMap
 from fava.core.conversion import cost_or_value
 from fava.core.inventory import CounterInventory
 from fava.core.inventory import SimpleCounterInventory
-from fava.util.typing import BeancountOptions
-from fava.util.typing import TypedDict
+
+if TYPE_CHECKING:
+    from fava.util.typing import BeancountOptions
 
 
-class SerialisedTreeNode(TypedDict):
+@dataclass
+class SerialisedTreeNode:
     """A serialised TreeNode."""
 
     account: str
     balance: SimpleCounterInventory
     balance_children: SimpleCounterInventory
-    children: "SerialisedTreeNode"  # type: ignore
+    children: list[SerialisedTreeNode]
 
 
 class TreeNode:
@@ -38,7 +42,7 @@ class TreeNode:
         #: Account name.
         self.name: str = name
         #: A list of :class:`.TreeNode`, its children.
-        self.children: List["TreeNode"] = []
+        self.children: list[TreeNode] = []
         #: The cumulative account balance.
         self.balance_children = CounterInventory()
         #: The account balance.
@@ -50,7 +54,7 @@ class TreeNode:
         self,
         conversion: str,
         price_map: PriceMap,
-        end: Optional[datetime.date],
+        end: datetime.date | None,
     ) -> SerialisedTreeNode:
         """Serialise the account.
 
@@ -61,14 +65,12 @@ class TreeNode:
             child.serialise(conversion, price_map, end)
             for child in self.children
         ]
-        return {
-            "account": self.name,
-            "balance_children": cost_or_value(
-                self.balance_children, conversion, price_map, end
-            ),
-            "balance": cost_or_value(self.balance, conversion, price_map, end),
-            "children": children,
-        }
+        return SerialisedTreeNode(
+            self.name,
+            cost_or_value(self.balance, conversion, price_map, end),
+            cost_or_value(self.balance_children, conversion, price_map, end),
+            children,
+        )
 
 
 class Tree(Dict[str, TreeNode]):
@@ -78,11 +80,11 @@ class Tree(Dict[str, TreeNode]):
         entries: A list of entries to compute balances from.
     """
 
-    def __init__(self, entries: Optional[Iterable[Directive]] = None):
+    def __init__(self, entries: Iterable[Directive] | None = None):
         super().__init__(self)
         self.get("", insert=True)
         if entries:
-            account_balances: Dict[
+            account_balances: dict[
                 str, CounterInventory
             ] = collections.defaultdict(CounterInventory)
             for entry in entries:
