@@ -5,7 +5,8 @@ really does hooks at the moment, works.
 """
 # mypy: ignore-errors
 # pylint: disable=missing-docstring
-# pragma: no cover - this is just an untested example
+from __future__ import annotations
+
 import os
 import subprocess
 
