@@ -7,19 +7,28 @@ representation of the entry is provided.
 
 This is not intended to work well enough for full roundtrips yet.
 """
+from __future__ import annotations
+
 import datetime
 import functools
 import re
 from typing import Any
-from typing import FrozenSet
-from typing import Tuple
 
 from beancount.core.amount import Amount
 from beancount.core.data import Balance
+from beancount.core.data import Close
+from beancount.core.data import Commodity
+from beancount.core.data import Custom
 from beancount.core.data import Directive
+from beancount.core.data import Document
 from beancount.core.data import EMPTY_SET
+from beancount.core.data import Event
 from beancount.core.data import Note
+from beancount.core.data import Open
+from beancount.core.data import Pad
 from beancount.core.data import Posting
+from beancount.core.data import Price
+from beancount.core.data import Query
 from beancount.core.data import Transaction
 from beancount.core.number import D
 from beancount.core.position import to_string as position_to_string
@@ -31,7 +40,7 @@ from fava.util.date import parse_date
 
 def extract_tags_links(
     string: str,
-) -> Tuple[str, FrozenSet[str], FrozenSet[str]]:
+) -> tuple[str | None, frozenset[str], frozenset[str]]:
     """Extract tags and links from a narration string.
 
     Args:
@@ -53,32 +62,59 @@ def extract_tags_links(
     return new_string, frozenset(tags), frozenset(links)
 
 
+ENTRY_TYPES = (
+    Open,
+    Close,
+    Commodity,
+    Pad,
+    Balance,
+    Transaction,
+    Note,
+    Event,
+    Query,
+    Price,
+    Document,
+    Custom,
+)
+
+
 @functools.singledispatch
-def serialise(entry: Directive) -> Any:
-    """Serialise an entry."""
-    if not entry:
-        return None
+def serialise(entry: Directive | Posting) -> Any:
+    """Serialise an entry or posting."""
+    assert isinstance(entry, ENTRY_TYPES), f"Unsupported object {entry}"
     ret = entry._asdict()
     ret["type"] = entry.__class__.__name__
-    if isinstance(entry, Transaction):
-        ret["payee"] = entry.payee or ""
-        if entry.tags:
-            ret["narration"] += " " + " ".join(["#" + t for t in entry.tags])
-        if entry.links:
-            ret["narration"] += " " + " ".join(
-                ["^" + link for link in entry.links]
-            )
-        del ret["links"]
-        del ret["tags"]
-        ret["postings"] = [serialise(pos) for pos in entry.postings]
-    elif ret["type"] == "Balance":
-        amt = ret["amount"]
-        ret["amount"] = {"number": str(amt.number), "currency": amt.currency}
     return ret
 
 
-@serialise.register(Posting)
-def _serialise_posting(posting: Posting) -> Any:
+@serialise.register
+def _(entry: Transaction) -> Any:
+    """Serialise an entry."""
+    ret = entry._asdict()
+    ret["type"] = "Transaction"
+    ret["payee"] = entry.payee or ""
+    if entry.tags:
+        ret["narration"] += " " + " ".join(["#" + n for n in entry.tags])
+    if entry.links:
+        ret["narration"] += " " + " ".join(["^" + n for n in entry.links])
+    del ret["links"]
+    del ret["tags"]
+    ret["postings"] = list(map(serialise, entry.postings))
+    return ret
+
+
+@serialise.register
+def _(entry: Balance) -> Any:
+    """Serialise an entry."""
+    ret = entry._asdict()
+    ret["type"] = "Balance"
+    amt = ret["amount"]
+    ret["amount"] = {"number": str(amt.number), "currency": amt.currency}
+    return ret
+
+
+@serialise.register
+def _(posting: Posting) -> Any:
     """Serialise a posting."""
     if isinstance(posting.units, Amount):
         position_str = position_to_string(posting)
@@ -125,7 +161,7 @@ def deserialise(json_entry: Any) -> Directive:
             date,
             json_entry.get("flag", ""),
             json_entry.get("payee", ""),
-            narration,
+            narration or "",
             tags,
             links,
             postings,
