@@ -2,14 +2,15 @@
 
 All functions in this module will be automatically added as template filters.
 """
+from __future__ import annotations
+
 import datetime
 import os
 import re
 import unicodedata
 from typing import Any
-from typing import List
 from typing import MutableMapping
-from typing import Optional
+from typing import TypeVar
 
 import flask
 from beancount.core import compare
@@ -27,21 +28,26 @@ from fava.core.conversion import units
 from fava.core.tree import TreeNode
 from fava.util.date import Interval
 
+MappingValue = TypeVar("MappingValue")
+
 
 def remove_keys(
-    _dict: MutableMapping[str, Any], keys: List[str]
-) -> MutableMapping[str, Any]:
+    _dict: MutableMapping[str, MappingValue] | None, keys: list[str]
+) -> MutableMapping[str, MappingValue]:
     """Remove keys from a dictionary."""
     if not _dict:
         return {}
     new = dict(_dict)
     for key in keys:
-        new.pop(key, None)
+        try:
+            del new[key]
+        except KeyError:
+            pass
     return new
 
 
 def cost_or_value(
-    inventory: Inventory, date: Optional[datetime.date] = None
+    inventory: Inventory, date: datetime.date | None = None
 ) -> Any:
     """Get the cost or value of an inventory."""
     return cost_or_value_without_context(
@@ -51,7 +57,7 @@ def cost_or_value(
 
 def format_currency(
     value: Decimal,
-    currency: Optional[str] = None,
+    currency: str | None = None,
     show_if_zero: bool = False,
     invert: bool = False,
 ) -> str:
@@ -71,13 +77,12 @@ def format_date(date: datetime.date) -> str:
         return date.strftime("%Y")
     if g.interval is Interval.QUARTER:
         return f"{date.year}Q{(date.month - 1) // 3 + 1}"
-    if g.interval is Interval.MONTH:
-        return date.strftime("%b %Y")
     if g.interval is Interval.WEEK:
         return date.strftime("%YW%W")
     if g.interval is Interval.DAY:
         return date.strftime("%Y-%m-%d")
-    return ""
+    assert g.interval is Interval.MONTH
+    return date.strftime("%b %Y")
 
 
 def hash_entry(entry: Directive) -> str:
@@ -113,19 +118,21 @@ def should_show(account: TreeNode) -> bool:
         should_show(a) for a in account.children
     ):
         return True
-    if account.name not in g.ledger.accounts:
+    ledger = g.ledger
+    if account.name not in ledger.accounts:
         return False
-    if not g.ledger.fava_options[
-        "show-closed-accounts"
-    ] and g.ledger.account_is_closed(account.name):
+    fava_options = ledger.fava_options
+    if not fava_options.show_closed_accounts and ledger.account_is_closed(
+        account.name
+    ):
         return False
     if (
-        not g.ledger.fava_options["show-accounts-with-zero-balance"]
+        not fava_options.show_accounts_with_zero_balance
         and account.balance.is_empty()
     ):
         return False
     if (
-        not g.ledger.fava_options["show-accounts-with-zero-transactions"]
+        not fava_options.show_accounts_with_zero_transactions
         and not account.has_txns
     ):
         return False
@@ -153,15 +160,8 @@ def format_errormsg(message: str) -> str:
 
 def collapse_account(account_name: str) -> bool:
     """Return true if account should be collapsed."""
-    collapse_patterns = g.ledger.fava_options["collapse-pattern"]
-    for pattern in collapse_patterns:
-        try:
-            if re.match(pattern, account_name):
-                return True
-        except re.error:
-            pass
-
-    return False
+    collapse_patterns = g.ledger.fava_options.collapse_pattern
+    return any(pattern.match(account_name) for pattern in collapse_patterns)
 
 
 FILTERS = [
