@@ -1,7 +1,11 @@
 # pylint: disable=missing-docstring
+from __future__ import annotations
+
 from babel.core import Locale  # type: ignore
 from beancount.core.number import D
+from pytest import MonkeyPatch
 
+from fava.core import FavaLedger
 from fava.core.number import get_locale_format
 
 
@@ -14,7 +18,7 @@ def test_get_locale_format() -> None:
     assert fmt(dec) == "1,00000000000000"
 
 
-def test_format_decimal(example_ledger) -> None:
+def test_format_decimal(example_ledger: FavaLedger) -> None:
     fmt = example_ledger.format_decimal
     assert fmt(D("12.333"), "USD") == "12.33"
     assert fmt(D("12.33"), "USD") == "12.33"
@@ -22,16 +26,18 @@ def test_format_decimal(example_ledger) -> None:
     assert fmt(D("12.333"), None) == "12.33"
 
 
-def test_format_decimal_locale(example_ledger, monkeypatch) -> None:
+def test_format_decimal_locale(
+    example_ledger: FavaLedger, monkeypatch: MonkeyPatch
+) -> None:
     fmt = example_ledger.format_decimal
 
-    monkeypatch.setitem(example_ledger.fava_options, "locale", "en_IN")
+    monkeypatch.setattr(example_ledger.fava_options, "locale", "en_IN")
     fmt.load_file()
     assert fmt(D("1111111.333"), "USD") == "11,11,111.33"
     assert fmt(D("11.333"), "USD") == "11.33"
     assert fmt(D("11.3333"), None) == "11.33"
 
-    monkeypatch.setitem(example_ledger.fava_options, "locale", "de_DE")
+    monkeypatch.setattr(example_ledger.fava_options, "locale", "de_DE")
     fmt.load_file()
     assert fmt(D("1111111.333"), "USD") == "1.111.111,33"
 
