@@ -1,14 +1,18 @@
 # pylint: disable=missing-docstring
+from __future__ import annotations
+
 from decimal import Decimal
 
+from flask import Flask
 from flask import get_template_attribute
 
+from .conftest import SnapshotFunc
 from fava.core.inventory import CounterInventory
 
 TREE_TABLE_PATH = "_tree_table.html"
 
 
-def test_render_diff_and_number(app, snapshot) -> None:
+def test_render_diff_and_number(app: Flask, snapshot: SnapshotFunc) -> None:
     with app.test_request_context("/long-example/"):
         app.preprocess_request()
         macro = get_template_attribute(
@@ -16,10 +20,10 @@ def test_render_diff_and_number(app, snapshot) -> None:
         )
 
         for invert in [False, True]:
-            balance = CounterInventory({"EUR": Decimal(12)})
-            cost = CounterInventory({"EUR": Decimal(10)})
+            balance = CounterInventory({"EUR": Decimal(12)})  # type: ignore
+            cost = CounterInventory({"EUR": Decimal(10)})  # type: ignore
             snapshot(macro(balance, cost, "EUR", invert))
         for invert in [False, True]:
-            balance = CounterInventory({"EUR": Decimal(10)})
-            cost = CounterInventory({"EUR": Decimal(12)})
+            balance = CounterInventory({"EUR": Decimal(10)})  # type: ignore
+            cost = CounterInventory({"EUR": Decimal(12)})  # type: ignore
             snapshot(macro(balance, cost, "EUR", invert))
